<?php
/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see bootstrap_preprocess_page()
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see bootstrap_process_page()
 * @see template_process()
 * @see html.tpl.php
 *
 * @ingroup themeable
 */
?>
<header id="header" role="header">
  <div class="container">
    <div class="header-top">
      <div class="row">
        <div class="col-sm-7">
          <?php print $accessibility_shortcuts ?>
        </div>
        <div class="col-sm-5">
          <ul class="accessibility">
            <?php if (isset($accessibility_page)): ?>
            <li>
              <?php print $accessibility_page ?>
            </li>
            <?php endif; ?>
            <li>
              <a href="javascript:void(0)" id="contrast"><?php print t('High contrast') ?></a>
            </li>
            <?php if (isset($accessibility_sitemap)): ?>
            <li>
              <?php print $accessibility_sitemap ?>
            </li>
            <?php endif; ?>
          </ul>
        </div>
      </div>
    </div>
    <div class="header-main">
      <div class="row">
        <div class="col-sm-8 info">
          <div class="site-info">
            <?php if ($logo): ?>
              <a class="logo navbar-btn pull-left" href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>">
                <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
              </a>
            <?php endif; ?>
            <a href="<?php print $front_page ?>">
              <span class="designation"><?php print $info_designation ?></span>
              <h1 class="site-name"><?php print $info_name ?></h1>
              <span class="subordination"><?php print $info_subordination ?></span>
            </a>
          </div>
        </div>
        <div class="col-sm-4">
          <?php if (isset($search_box)): ?>
          <div class="search">
            <?php print $search_box ?>
          </div>
          <?php endif; ?>

          <?php if ($social_links): ?>
          <div class="social">
            <?php print $social_links ?>
          </div>
          <?php endif ?>
        </div>
      </div>
    </div>
  </div>
</header>
<div id="navbar">
  <div class="container">
    <!-- .btn-navbar is used as the toggle for collapsed navbar content -->

    <?php if (!empty($secondary_nav)): ?>
      <div>
        <nav role="navigation">
          <?php print render($secondary_nav); ?>
        </nav>
      </div>
    <?php endif; ?>
  </div>
</div>


<div id="main" class="main-container container">

  <header role="banner" id="page-header">
    <?php if (!empty($site_slogan)): ?>
      <p class="lead"><?php print $site_slogan; ?></p>
    <?php endif; ?>
<?php if (!empty($breadcrumb)): print $breadcrumb; endif;?>
    <?php print render($page['header']); ?>
  </header> <!-- /#page-header -->

  <div class="row">

    <?php if (!empty($page['sidebar_first'])): ?>
      <aside class="col-sm-3" role="complementary" id="sidebar-first-menu">
    <h4>
        <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
            Menu
           <span>
               <span class="sr-only">Toggle navigation</span>
               <span class="icon-bar"></span>
               <span class="icon-bar"></span>
               <span class="icon-bar"></span>
           </span>
       </button>
    </h4>
      <div class="navbar-collapse collapse">
        <nav role="navigation">
          <?php print render($page['sidebar_first']); ?>
        </nav>
      </div>
      </aside>  <!-- /#sidebar-first -->
    <?php endif; ?>

    <section<?php print $content_column_class; ?>>
      <a id="main-content"></a>
      <?php print render($title_prefix); ?>
      <?php if (!empty($title)): ?>
        <h1 class="page-header"><?php print $title; ?></h1>
      <?php endif; ?>
      <?php print render($title_suffix); ?>
      <?php print $messages; ?>
      <?php if (!empty($tabs)): ?>
        <?php print render($tabs); ?>
      <?php endif; ?>
      <?php if (!empty($page['help'])): ?>
        <?php print render($page['help']); ?>
      <?php endif; ?>
      <?php if (!empty($action_links)): ?>
        <ul class="action-links"><?php print render($action_links); ?></ul>
      <?php endif; ?>
      <?php print render($page['content']); ?>
    </section>

    <?php if (!empty($page['sidebar_second'])): ?>
      <aside class="col-sm-3" role="complementary">
        <?php print render($page['sidebar_second']); ?>
      </aside>  <!-- /#sidebar-second -->
    <?php endif; ?>
  </div>
</div>
<footer id="footer">
  <?php if ($page['footer_firstcolumn'] || $page['footer_secondcolumn'] || $page['footer_thirdcolumn'] || $page['footer_fourthcolumn'] || $page['footer']): ?>
  <div class="footer">
    <div class="container">
      <div class="row">
        <div class="footer-column col-sm-6 col-md-3">
          <?php print render($page['footer_firstcolumn']); ?>
        </div>
        <div class="footer-column col-sm-6 col-md-3">
          <?php print render($page['footer_secondcolumn']); ?>
        </div>
        <div class="footer-column col-sm-6 col-md-3">
          <?php print render($page['footer_thirdcolumn']); ?>
        </div>
        <div class="footer-column col-sm-6 col-md-3">
          <?php print render($page['footer_fourthcolumn']); ?>
        </div>
      </div>
    </div>
  </div>
  <?php endif; ?>

  <!-- Footer Brasil -->
  <div id="footer-brasil" class="no-contrast"></div>

    <div class="container">
      <div class="row">
        <div class="col-sm-12">
          <?php print render($page['footer']); ?>
        </div>
      </div>
    </div>
</footer>
